### R code from vignette source 'mixlow.Rnw'

###################################################
### code chunk number 1: preliminaries
###################################################
options(prompt = "R> ", continue = "+  ")


###################################################
### code chunk number 2: load_data
###################################################
library("mixlow")
dataFile <- "A549_vin_topo_data.txt"

trayData <- readDataFile(system.file("exdata", dataFile, package="mixlow"))

trays <- getTrays(data=trayData) 
drugs <- getDrugs(data=trayData)
cellLines <- getCellLines(data=trayData)


###################################################
### code chunk number 3: prepare_data
###################################################
mixlowData <- prepareData(trayData=trayData, trays=trays[1:9], 
    cellLines=cellLines[1]) 
summary(mixlowData)


###################################################
### code chunk number 4: NLS
###################################################
parameterDefaults <- getNlsParameterDefaults(trays=trays[1:9])
parameterDefaults["vin_tr1","param.lambda"] <- .2 
parameterDefaults["vin_tr2","param.lambda"] <- .2 
parameterDefaults["vin_tr3","param.lambda"] <- .2
nlsData <- doNls(mixlowData=mixlowData, parameterDefaults)  
summary(nlsData)


###################################################
### code chunk number 5: NLME
###################################################
nlmeData <- doNlme(mixlowData=mixlowData, nlsData=nlsData, analysis="multiple", 
    varFunction=4) 
summary(nlmeData)


###################################################
### code chunk number 6: Loewe1
###################################################
loeweData <- doLoewe(mixlowData, nlmeData) 
summary(loeweData)


###################################################
### code chunk number 7: Loewe2 (eval = FALSE)
###################################################
## loeweData <- doLoewe(mixlowData, nlmeData) 
## plot(loeweData)


###################################################
### code chunk number 8: Loewe-fig
###################################################
par(mfrow = c(1, 2))
loeweData <- doLoewe(mixlowData, nlmeData) 
plot(loeweData)


###################################################
### code chunk number 9: anova
###################################################
nlmeData1 <- doNlme(mixlowData=mixlowData, nlsData= nlsData, drugs=drugs[1:3], 
    analysis="multiple", varFunction=3)
nlmeData2 <- doNlme(mixlowData=mixlowData, nlsData= nlsData, drugs=drugs[1:3], 
   analysis="multiple", varFunction=4)
model1 <- nlmeData1$nlmeModels[[1]]
model2 <- nlmeData2$nlmeModels[[1]]
anova(model1,model2)


